import { ContractFunction, EndpointDefinition } from "../abi";
import { Address } from "../core";
import { Transaction } from "../core/transaction";
import * as resources from "./resources";
interface IConfig {
    chainID: string;
    addressHrp: string;
    minGasLimit: bigint;
    gasLimitPerByte: bigint;
    gasLimitClaimDeveloperRewards: bigint;
    gasLimitChangeOwnerAddress: bigint;
}
interface IAbi {
    constructorDefinition: EndpointDefinition;
    upgradeConstructorDefinition?: EndpointDefinition;
    getEndpoint(name: string | ContractFunction): EndpointDefinition;
}
/**
 * Use this class to create transactions to deploy, call or upgrade a smart contract.
 */
export declare class SmartContractTransactionsFactory {
    private readonly config;
    private readonly abi?;
    private readonly tokenComputer;
    private readonly dataArgsBuilder;
    private readonly contractDeployAddress;
    constructor(options: {
        config: IConfig;
        abi?: IAbi;
    });
    createTransactionForDeploy(sender: Address, options: resources.ContractDeployInput): Transaction;
    createTransactionForExecute(sender: Address, options: resources.ContractExecuteInput): Transaction;
    createTransactionForUpgrade(sender: Address, options: resources.ContractUpgradeInput): Transaction;
    private getEndpointForUpgrade;
    createTransactionForClaimingDeveloperRewards(options: {
        sender: Address;
        contract: Address;
    }): Transaction;
    createTransactionForChangingOwnerAddress(options: {
        sender: Address;
        contract: Address;
        newOwner: Address;
    }): Transaction;
    private argsToDataParts;
    private areArgsOfTypedValue;
}
export {};
